%% Matlab script to generate figures for Biometrika paper.
%%%%%%%%%%%%%%%%%%%%%%%
%% First GRB T1425-C1.
%%%%%%%%%%%%%%%%%%%%%%%
%% Load data for burst and fit from Norris et al. (1996).
% Data are from BATSE gamma-ray burst T1425, channel 1, with
% the photon arrival times aggregated up to 64ms time bins.
% First 256 such bins are selected, as these contain the main
% part of the burst (as shown in Norris et al (1996), Fig20).

load burstdata.mat	%% This should contain datavec256; fits; 
			%% cal datavec256 -> datavec.

%%
% Generate figure of data alone.
%%
clf
bins = [0:1:255]*64./1000;
h=plot(bins,datavec,'b.')
set(h,'LineWidth',2);
axis([min(bins) max(bins) 100 700])
t=ylabel('Counts'); set(t,'FontSize',20); 
t=xlabel('Seconds');set(t,'FontSize',20);

pause

%%
% Example with piecwise linear Poisson model.
%%

% Compute MS-GLM fit using piecewise linear Poisson model.
m=1;
[bp, est] = MSGLMPois_RP(datavec,m);

% Generate figure with both sets of estimates i.e., ours and
% that from Norris et al.
clf
h=plot(bins,datavec,'b.')
set(h,'LineWidth',2);
axis([min(bins) max(bins) 100 700])

t=ylabel('Counts'); set(t,'FontSize',20); 
t=xlabel('Seconds');set(t,'FontSize',20);

hold
h=plot(bins,norrisfitvec,'k-.')
set(h,'LineWidth',2);

h=plot(bins,est,'r')
set(h,'LineWidth',2);

if length(bp) > 0,
  Msig = 1.10*max(xx); msig = min(xx);
  for i=2:length(bp),
    bploc = bins(bp(i)) + (1/(2*256));
    h=plot([bploc, bploc], [msig,Msig], 'm:')
    set(h,'LineWidth',3);

  end
end
pause

%%
% Example with piecwise quadratic Poisson model.
%%

% Compute MS-GLM fit using piecewise quadratic Poisson model.
m=2;
[bp, est] = MSGLMPois_RP(datavec,m);

% Generate figure with both sets of estimates, for quadratic case.
clf
h=plot(bins,datavec,'b.')
set(h,'LineWidth',2);

axis([min(bins) max(bins) 100 700])
t=ylabel('Counts'); set(t,'FontSize',20); 
t=xlabel('Seconds');set(t,'FontSize',20);

hold
h=plot(bins,norrisfitvec,'k-.')
set(h,'LineWidth',2);

h=plot(bins,est,'r')
set(h,'LineWidth',2);

if length(bp) > 0,
  Msig = 1.10*max(xx); msig = min(xx);
  for i=2:length(bp),
    bploc = bins(bp(i)) + (1/(2*256));
    h=plot([bploc, bploc], [msig,Msig], 'm:')
    set(h,'LineWidth',3);

  end
end
pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Second, generate figures for analysis of packet loss data.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear

% Load packet loss data.  Data represents sub-sampling of original
% packet trace of Yajnik et al (1999).  Originally, packets were
% send between UMass-Amherst and SCIS regularly every 160ms.
% Data represents sub-sampling of packet data trace, to a rate of 1000ms.
% Then packet loss information was aggregated over 5 minute intervals.  
% End result is a time series of binomial observations, with n=300 each and
% p changing as a function of time and reflecting the underlying
% rate of packet loss.

load packetdata.mat

%%
% Plot of data alone.
%%
clf
%subplot(211)
h=plot(tt,xx./nn,'.')
set(h,'LineWidth',2);

t=xlabel('Hours')
set(t,'Fontsize',20)
t=ylabel('Packet Loss Rate')
set(t,'Fontsize',20)
axis([0 max(tt) 0 0.25])
%title('Trace #3 of Yajnik et al (1999): 1000ms sampling, 5 minute bins')
pause

%%
% Plot of data with estimate.
%%

% Compute MS-GLM fit with piecewise linear Binomial model.
m = 1;
[bp, est] = MSGLMBinom_RP([xx nn],m);

% Plot data and estimate.
h=plot(tt,xx./nn,'b.')
set(h,'LineWidth',2);

axis([0 max(tt) 0 0.25])
hold on
h=plot(tt,est,'r')
set(h,'LineWidth',2)
if length(bp) > 0,
  Msig = 1.10*max(xx./nn); msig = min(xx./nn);
  for i=2:length(bp),
    bploc = tt(bp(i)) + (1/(2*length(xx)));
    h=plot([bploc, bploc], [msig,Msig],'m:')
    set(h,'LineWidth',3)
  end
end
t=xlabel('Hours')
set(t,'Fontsize',20)
t=ylabel('Packet Loss Rate')
set(t,'Fontsize',20)

%title('MS-GLM Analysis of Trace #3: Estimated loss rate (solid red lines) and segmentation (vertical, dotted lines)') 
